@@ -5,7 +5,7 @@ import jax
 import jax.numpy as jnp
 import numpy as onp
 import haiku as hk
-from gym.spaces import Space, Discrete
+from gymnasium.spaces import Space, Discrete
 
 from ..utils import safe_sample, batch_to_single, jit
 from .base_func import BaseFunc, ExampleData, Inputs, ArgsType1, ArgsType2, ModelTypes
@@ -188,7 +188,7 @@ class BaseStochasticFuncType1(BaseFunc):
             s       &\mapsto p(s'|s,.)  &\qquad (\text{modeltype} &= 2)
 
         Note that modeltype=2 is only well-defined if the action space is :class:`Discrete
-        <gym.spaces.Discrete>`. Namely, :math:`n` is the number of discrete actions.
+        <gymnasium.spaces.Discrete>`. Namely, :math:`n` is the number of discrete actions.
 
         """
         return self._modeltype
@@ -200,11 +200,12 @@ class BaseStochasticFuncType1(BaseFunc):
 
         if not isinstance(env.observation_space, Space):
             raise TypeError(
-                "env.observation_space must be derived from gym.Space, "
+                "env.observation_space must be derived from gymnasium.Space, "
                 f"got: {type(env.observation_space)}")
         if not isinstance(env.action_space, Space):
             raise TypeError(
-                f"env.action_space must be derived from gym.Space, got: {type(env.action_space)}")
+                "env.action_space must be derived from gymnasium.Space, "
+                f"got: {type(env.action_space)}")
 
         rnd = onp.random.RandomState(random_seed)
         rngs = hk.PRNGSequence(rnd.randint(jnp.iinfo('int32').max))
