@@ -14,9 +14,10 @@ class Policy(BaseStochasticFuncType2):
 
         A Haiku-style function that specifies the forward pass.
 
-    env : gym.Env
+    env : gymnasium.Env
 
-        The gym-style environment. This is used to validate the input/output structure of ``func``.
+        The gymnasium-style environment. This is used to validate the input/output structure of
+        ``func``.
 
     observation_preprocessor : function, optional
 
