@@ -5,7 +5,7 @@ import jax
 import jax.numpy as jnp
 import numpy as onp
 import haiku as hk
-from gym.spaces import Space, Discrete
+from gymnasium.spaces import Space, Discrete
 
 from ..utils import safe_sample, default_preprocessor
 from ..value_transforms import ValueTransform
@@ -29,9 +29,11 @@ class Q(BaseFunc):
         A Haiku-style function that specifies the forward pass. The function signature must be the
         same as the example below.
 
-    env : gym.Env
+    env : gymnasium.Env
 
-        The gym-style environment. This is used to validate the input/output structure of ``func``.
+        The gymnasium-style environment. This is used to validate the input/output structure of
+        ``func``.
+        ``func``.
 
     observation_preprocessor : function, optional
 
@@ -199,7 +201,7 @@ class Q(BaseFunc):
             s       &\mapsto q(s,.)\in\mathbb{R}^n  &\qquad (\text{modeltype} &= 2)
 
         Note that modeltype=2 is only well-defined if the action space is :class:`Discrete
-        <gym.spaces.Discrete>`. Namely, :math:`n` is the number of discrete actions.
+        <gymnasium.spaces.Discrete>`. Namely, :math:`n` is the number of discrete actions.
 
         """
         return self._modeltype
@@ -211,7 +213,7 @@ class Q(BaseFunc):
 
         if not isinstance(env.observation_space, Space):
             raise TypeError(
-                "env.observation_space must be derived from gym.Space, "
+                "env.observation_space must be derived from gymnasium.Space, "
                 f"got: {type(env.observation_space)}")
 
         if observation_preprocessor is None:
