@@ -48,6 +48,7 @@ class ModelUpdater:
         A stochastic regularizer, see :mod:`coax.regularizers`.
 
     """
+
     def __init__(self, model, optimizer=None, loss_function=None, regularizer=None):
         if not (is_reward_function(model) or is_transition_model(model)):
             raise TypeError(f"model must be a dynamics model, got: {type(model)}")
@@ -133,7 +134,7 @@ class ModelUpdater:
 
         """
         grads, function_state, metrics = self.grads_and_metrics(transition_batch)
-        if any(jnp.any(jnp.isnan(g)) for g in jax.tree_leaves(grads)):
+        if any(jnp.any(jnp.isnan(g)) for g in jax.tree_util.tree_leaves(grads)):
             raise RuntimeError(f"found nan's in grads: {grads}")
         self.apply_grads(grads, function_state)
         return metrics
@@ -205,8 +206,9 @@ class ModelUpdater:
 
     @optimizer.setter
     def optimizer(self, new_optimizer):
-        new_optimizer_state_structure = jax.tree_structure(new_optimizer.init(self.model.params))
-        if new_optimizer_state_structure != jax.tree_structure(self.optimizer_state):
+        new_optimizer_state_structure = jax.tree_util.tree_structure(
+            new_optimizer.init(self.model.params))
+        if new_optimizer_state_structure != jax.tree_util.tree_structure(self.optimizer_state):
             raise AttributeError("cannot set optimizer attr: mismatch in optimizer_state structure")
         self._optimizer = new_optimizer
 
@@ -216,6 +218,8 @@ class ModelUpdater:
 
     @optimizer_state.setter
     def optimizer_state(self, new_optimizer_state):
-        if jax.tree_structure(new_optimizer_state) != jax.tree_structure(self.optimizer_state):
+        new_tree_structure = jax.tree_util.tree_structure(new_optimizer_state)
+        tree_structure = jax.tree_util.tree_structure(self.optimizer_state)
+        if new_tree_structure != tree_structure:
             raise AttributeError("cannot set optimizer_state attr: mismatch in tree structure")
         self._optimizer_state = new_optimizer_state
