@@ -1,6 +1,6 @@
 from enum import Enum
 
-import gym
+import gymnasium
 import numpy as onp
 import haiku as hk
 import jax
@@ -31,10 +31,10 @@ class ProbaDist(BaseProbaDist):
 
     Parameters
     ----------
-    space : gym.Space
+    space : gymnasium.Space
 
-        The gym-style space that specifies the domain of the distribution. This may be any space
-        included in the :mod:`gym.spaces` module.
+        The gymnasium-style space that specifies the domain of the distribution. This may be any
+        space included in the :mod:`gymnasium.spaces` module.
 
     """
     __slots__ = BaseProbaDist.__slots__ + ('_structure', '_structure_type')
@@ -42,22 +42,22 @@ class ProbaDist(BaseProbaDist):
     def __init__(self, space):
         super().__init__(space)
 
-        if isinstance(self.space, gym.spaces.Discrete):
+        if isinstance(self.space, gymnasium.spaces.Discrete):
             self._structure_type = StructureType.LEAF
             self._structure = CategoricalDist(space)
-        elif isinstance(self.space, gym.spaces.Box):
+        elif isinstance(self.space, gymnasium.spaces.Box):
             self._structure_type = StructureType.LEAF
             self._structure = NormalDist(space)
-        elif isinstance(self.space, gym.spaces.MultiDiscrete):
+        elif isinstance(self.space, gymnasium.spaces.MultiDiscrete):
             self._structure_type = StructureType.LIST
-            self._structure = [self.__class__(gym.spaces.Discrete(n)) for n in space.nvec]
-        elif isinstance(self.space, gym.spaces.MultiBinary):
+            self._structure = [self.__class__(gymnasium.spaces.Discrete(n)) for n in space.nvec]
+        elif isinstance(self.space, gymnasium.spaces.MultiBinary):
             self._structure_type = StructureType.LIST
-            self._structure = [self.__class__(gym.spaces.Discrete(2)) for _ in range(space.n)]
-        elif isinstance(self.space, gym.spaces.Tuple):
+            self._structure = [self.__class__(gymnasium.spaces.Discrete(2)) for _ in range(space.n)]
+        elif isinstance(self.space, gymnasium.spaces.Tuple):
             self._structure_type = StructureType.LIST
             self._structure = [self.__class__(sp) for sp in space.spaces]
-        elif isinstance(self.space, gym.spaces.Dict):
+        elif isinstance(self.space, gymnasium.spaces.Dict):
             self._structure_type = StructureType.DICT
             self._structure = {k: self.__class__(sp) for k, sp in space.spaces.items()}
         else:
@@ -239,19 +239,19 @@ class ProbaDist(BaseProbaDist):
             return self._structure.postprocess_variate(
                 next(rngs), X, index=index, batch_mode=batch_mode)
 
-        if isinstance(self.space, (gym.spaces.MultiDiscrete, gym.spaces.MultiBinary)):
+        if isinstance(self.space, (gymnasium.spaces.MultiDiscrete, gymnasium.spaces.MultiBinary)):
             assert self._structure_type == StructureType.LIST
             return onp.stack([
                 dist.postprocess_variate(next(rngs), X[i], index=index, batch_mode=batch_mode)
                 for i, dist in enumerate(self._structure)], axis=-1)
 
-        if isinstance(self.space, gym.spaces.Tuple):
+        if isinstance(self.space, gymnasium.spaces.Tuple):
             assert self._structure_type == StructureType.LIST
             return tuple(
                 dist.postprocess_variate(next(rngs), X[i], index=index, batch_mode=batch_mode)
                 for i, dist in enumerate(self._structure))
 
-        if isinstance(self.space, gym.spaces.Dict):
+        if isinstance(self.space, gymnasium.spaces.Dict):
             assert self._structure_type == StructureType.DICT
             return {
                 k: dist.postprocess_variate(next(rngs), X[k], index=index, batch_mode=batch_mode)
@@ -267,7 +267,7 @@ class ProbaDist(BaseProbaDist):
         if self._structure_type == StructureType.LEAF:
             return self._structure.preprocess_variate(next(rngs), X)
 
-        if isinstance(self.space, (gym.spaces.MultiDiscrete, gym.spaces.MultiBinary)):
+        if isinstance(self.space, (gymnasium.spaces.MultiDiscrete, gymnasium.spaces.MultiBinary)):
             assert self._structure_type == StructureType.LIST
             return [
                 dist.preprocess_variate(next(rngs), X[..., i])
