@@ -5,10 +5,6 @@ Utilities
 
 This is a collection of utility (helper) functions used throughout the package.
 
-
-Object Reference
-----------------
-
 .. autosummary::
     :nosignatures:
 
@@ -49,6 +45,7 @@ Object Reference
     coax.utils.jit
     coax.utils.load
     coax.utils.loads
+    coax.utils.make_dmc
     coax.utils.merge_dicts
     coax.utils.pretty_print
     coax.utils.pretty_repr
@@ -60,10 +57,67 @@ Object Reference
     coax.utils.safe_sample
     coax.utils.single_to_batch
     coax.utils.stack_trees
+    coax.utils.sync_shared_params
     coax.utils.tree_ravel
     coax.utils.unvectorize
 
 
+Object Reference
+----------------
+
+.. autoclass:: coax.utils.OrnsteinUhlenbeckNoise
+.. autoclass:: coax.utils.StepwiseLinearFunction
+.. autoclass:: coax.utils.SegmentTree
+.. autoclass:: coax.utils.SumTree
+.. autoclass:: coax.utils.MinTree
+.. autoclass:: coax.utils.MaxTree
+.. autofunction:: coax.utils.argmax
+.. autofunction:: coax.utils.argmin
+.. autofunction:: coax.utils.batch_to_single
+.. autofunction:: coax.utils.check_array
+.. autofunction:: coax.utils.check_preprocessors
+.. autofunction:: coax.utils.clipped_logit
+.. autofunction:: coax.utils.default_preprocessor
+.. autofunction:: coax.utils.diff_transform
+.. autofunction:: coax.utils.diff_transform_matrix
+.. autofunction:: coax.utils.docstring
+.. autofunction:: coax.utils.double_relu
+.. autofunction:: coax.utils.dump
+.. autofunction:: coax.utils.dumps
+.. autofunction:: coax.utils.enable_logging
+.. autofunction:: coax.utils.generate_gif
+.. autofunction:: coax.utils.get_env_attr
+.. autofunction:: coax.utils.get_grads_diagnostics
+.. autofunction:: coax.utils.get_magnitude_quantiles
+.. autofunction:: coax.utils.get_transition_batch
+.. autofunction:: coax.utils.has_env_attr
+.. autofunction:: coax.utils.idx
+.. autofunction:: coax.utils.is_policy
+.. autofunction:: coax.utils.is_qfunction
+.. autofunction:: coax.utils.is_reward_function
+.. autofunction:: coax.utils.is_stochastic
+.. autofunction:: coax.utils.is_transition_model
+.. autofunction:: coax.utils.is_vfunction
+.. autofunction:: coax.utils.isscalar
+.. autofunction:: coax.utils.jit
+.. autofunction:: coax.utils.load
+.. autofunction:: coax.utils.loads
+.. autofunction:: coax.utils.make_dmc
+.. autofunction:: coax.utils.merge_dicts
+.. autofunction:: coax.utils.pretty_print
+.. autofunction:: coax.utils.pretty_repr
+.. autofunction:: coax.utils.quantiles
+.. autofunction:: coax.utils.quantiles_uniform
+.. autofunction:: coax.utils.quantile_cos_embedding
+.. autofunction:: coax.utils.reload_recursive
+.. autofunction:: coax.utils.render_episode
+.. autofunction:: coax.utils.safe_sample
+.. autofunction:: coax.utils.single_to_batch
+.. autofunction:: coax.utils.stack_trees
+.. autofunction:: coax.utils.sync_shared_params
+.. autofunction:: coax.utils.tree_ravel
+.. autofunction:: coax.utils.unvectorize
+
 """
 
 from ._action_noise import OrnsteinUhlenbeckNoise
@@ -89,6 +143,7 @@ from ._array import (
     safe_sample,
     single_to_batch,
     stack_trees,
+    sync_shared_params,
     tree_ravel,
     unvectorize,
 )
@@ -116,6 +171,7 @@ from ._misc import (
 )
 from ._segment_tree import SegmentTree, SumTree, MinTree, MaxTree
 from ._quantile_funcs import quantiles, quantiles_uniform, quantile_cos_embedding
+from ._dmc_gym import make_dmc
 
 
 __all__ = (
@@ -157,6 +213,7 @@ __all__ = (
     'jit',
     'load',
     'loads',
+    'make_dmc',
     'merge_dicts',
     'pretty_print',
     'pretty_repr',
@@ -168,6 +225,7 @@ __all__ = (
     'safe_sample',
     'single_to_batch',
     'stack_trees',
+    'sync_shared_params',
     'tree_ravel',
     'unvectorize',
 )
